#!/bin/sh

#The purpose of this script is to import new media files using a systematic acquisition process.
#This script performs the following operations:
# 1. Identify source files and target destination.
# 2. Create a new folder in the HRW project folder within "originals" named after today's date and the Videographer's name. This folder is the target destination.
# 3. Transfer source files to this target destination using rsync command. Logs from this trasfer are stored in the project "logs" folder.
# 4. Print a label for the external hard drive associated with this acquisition.
# 4. Create checksums for all media transfered in this ingest. Store checksum file in the "logs" folder.

#Receive user input for source, destination, and folder and log naming
tput setaf 6; echo "Please drag and drop source media here"
read sourceData
tput setaf 7; echo "Please drag and drop HRW project here"
read projectLocation
tput setaf 6; echo "Please enter the videographer or resesarcher's name (no spaces). Ex: "Emina-Cerimovic""
read agentName

#Feedback to the user
echo "    "
tput setaf 7; echo "   file transfer in progress..."
echo "    "

#Print Labels
printf "\n$(basename "$projectLocation\n$agentName")" > $projectLocation/logs/$(date +"%Y-%m-%d_")"$agentName"-label.txt
lpr -P Brother_QL_820NWB___neptune -o PageSize=DK-2214 -o landscape $projectLocation/logs/$(date +"%Y-%m-%d_")"$agentName"-label.txt

#Perform archival file transfer via RSYNC
rsync -va --progress --stats "$sourceData" $projectLocation/originals/$(date +"%Y-%m-%d_")"$agentName"/ > $projectLocation/logs/$(date +"%Y-%m-%d_")"$agentName"-output.log

#osascript -e 'tell application "Terminal" to activate' -e 'tell application "System Events" to tell process "Terminal" to keystroke "t" using command down' -e 'tell application "Terminal" to do script "less +F $projectLocation/logs/$(date +"%Y-%m-%d_")"$agentName"-output.log" in selected tab of the front window'
#Feedback to the user
echo "    "
tput setaf 2; echo "**********transfer complete**********"
echo "    "

sleep 2

tput setaf 7; echo "  file verification in progress..."
echo "    "
echo "    "

#Perform MD5 and SHA-1 Checksums via Hashdeep
hashdeep -bre $projectLocation/originals/$(date +"%Y-%m-%d_")"$agentName"/* > $projectLocation/logs/$(date +"%Y-%m-%d_")"$agentName"-checksums.log

#Perform basic disk usage comparison
#du -sch $sourceData/*
#echo
#echo ======================
#echo
#du -sch $projectLocation/originals/$(date +"%Y-%m-%d_")"$agentName"/*


#Feedback to the user
tput setaf 2; echo "**********operation complete**********"
tput sgr0; echo "done"
echo "    "
tput bel


#
